@@ -67,6 +67,7 @@ class patch:
 
 class surface:
     def __init__(self):
+        self.other_surface = None
         pass
     def load(self,filename):
         points,normals = load3d(filename)
@@ -384,7 +385,10 @@ class surface:
         self.CDD = CDD
         """
     def within(self,x,y,z,k):
-        return self.DD[0]([x,y,z,k]) < 0
+        if self.other_surface is None:
+            return self.DD[0]([x,y,z,k]) < 0
+        else:
+            return (self.DD[0]([x,y,z,k]) < 0 and self.other_surface.DD[0]([x,y,z,k]) > 0)
 
     def pick(self,**kwargs):
         homogeneous = kwargs.get('homogeneous',False)
@@ -536,6 +540,9 @@ class surface:
         self.volume= volume
         self.surface_area = surface_area
 
+    def subtract(self,other_surface):
+        self.other_surface
+
 def marching_cubes(surface_object,resolution=20,k=2,level=0,visualize=False):
     """
     Takes an interpolated volume and performs
