@@ -500,6 +500,7 @@ def contour_check_all(interps,radius_buffer):
         if len(collision_contours) > 0:
             pass
             #plot_path_contours(contours,t_list,highlight=list(collision_contours))
+        tmp_t.append(t_list[0])
         for idx in range(len(collision_free)-1):
             tmp_t.append(t_list[collision_free[idx]])
             if collision_free[idx+1] - collision_free[idx]>1:
@@ -510,6 +511,7 @@ def contour_check_all(interps,radius_buffer):
                 if f_op < 0:
                     tmp_t.append(t_op)
         tmp_t.append(t_list[collision_free[-1]])
+        tmp_t.append(t_list[-1])
         if len(collision_contours) > 0:
             pass
             #plot_path_contours(contours,tmp_t)
